@@ -1,31 +1,26 @@
 package Mojo::Webqq::Plugin::ShowMsg;
-our $PRIORITY = 100;
 use POSIX qw(strftime);
-use List::Util qw(first);
 sub call{
     my $client = shift;
-    my $data = shift;
     $client->on(
         receive_message=>sub{
             my($client,$msg)=@_; 
             if($msg->type eq 'message'){
-                my $sender_nick = $msg->sender->displayname;
-                my $sender_category = $msg->sender->category || "好友";
+                my $sender_nick = $msg->sender->markname || $msg->sender->nick;
+                my $sender_categorie = $msg->sender->categorie || "好友";
                 #my $receiver_nick = $msg->receiver->nick;
                 my $receiver_nick = "我";
-                $client->info({time=>$msg->msg_time,level=>"好友消息",title=>"$sender_nick|$sender_category :"},$msg->content);
+                $client->info({time=>$msg->msg_time,level=>"好友消息",title=>"$sender_nick|$sender_categorie :"},$msg->content);
                 
             }
             elsif($msg->type eq 'group_message'){
                 my $gname = $msg->group->gname;
-                my $sender_nick = $msg->sender->displayname;
-                return if ref $data->{ban_group}  eq "ARRAY" and first {$_=~/^\d+$/?$msg->group->gnumber eq $_:$gname eq $_} @{$data->{ban_group}};
-                return if ref $data->{allow_group}  eq "ARRAY" and !first {$_=~/^\d+$/?$msg->group->gnumber eq $_:$gname eq $_} @{$data->{allow_group}};
+                my $sender_nick = $msg->sender->card || $msg->sender->nick;
                 $client->info({time=>$msg->msg_time,level=>"群消息",title=>"$sender_nick|$gname :"},$msg->content);
             }
             elsif($msg->type eq 'discuss_message'){
                 my $dname = $msg->discuss->dname;
-                my $sender_nick = $msg->sender->displayname;
+                my $sender_nick = $msg->sender->nick;
                 $client->info({time=>$msg->msg_time,level=>"讨论组消息",title=>"$sender_nick|$dname :"},$msg->content);
             }
             elsif($msg->type eq 'sess_message'){
@@ -34,12 +29,12 @@ sub call{
                 my $gname;
                 my $dname;
                 if($msg->via eq "group"){
-                    $sender_nick = $msg->sender->displayname;
+                    $sender_nick = $msg->sender->card||$msg->sender->nick;
                     $gname = $msg->group->gname;
                     $client->info({time=>$msg->msg_time,level=>"群临时消息",title=>"$sender_nick|$gname :"},$msg->content);
                 }
                 elsif($msg->via eq "discuss"){
-                    $sender_nick = $msg->sender->displayname;
+                    $sender_nick = $msg->sender->nick;
                     $dname = $msg->discuss->dname;
                     $client->info({time=>$msg->msg_time,level=>"讨论组临时消息",title=>"$sender_nick|$dname :"},$msg->content);
                 }
@@ -47,29 +42,21 @@ sub call{
         },
         send_message=>sub{
             my($client,$msg,$status)=@_;
-            my $attach = '';
-            if($status->is_success){
-                if(defined $status->info and $status->info ne "发送正常" ){
-                    $attach = "[" . $status->info . "]";
-                }
-            }
-            else{
-                $attach = "[发送失败".(defined $status->info?"(".$status->info.")":"") . "]";
-            }
+            my $attach = $status->is_success?"":"[发送失败]";
             if($msg->type eq 'message'){
                 my $sender_nick = "我";
-                my $receiver_nick = $msg->receiver->displayname;
-                $client->info({time=>$msg->msg_time,level=>"好友消息",title=>"$sender_nick->$receiver_nick :"},$msg->content . $attach);
+                my $receiver_nick = $msg->receiver->markname || $msg->receiver->nick;
+                $client->info({time=>$msg->msg_time,level=>"好友消息",title=>"$sender_nick->$receiver_nick :"},$msg->content);
             }
             elsif($msg->type eq 'group_message'){
                 my $gname = $msg->group->gname;
                 my $sender_nick = "我";
-                $client->info({time=>$msg->msg_time,level=>"群消息",title=>"$sender_nick->$gname :"},$msg->content . $attach);
+                $client->info({time=>$msg->msg_time,level=>"群消息",title=>"$sender_nick->$gname :"},$msg->content);
             }
             elsif($msg->type eq 'discuss_message'){
                 my $dname = $msg->discuss->dname;
                 my $sender_nick = "我";
-                $client->info({time=>$msg->msg_time,level=>"讨论组消息",title=>"$sender_nick->$dname :"},$msg->content . $attach);
+                $client->info({time=>$msg->msg_time,level=>"讨论组消息",title=>"$sender_nick->$dname :"},$msg->content);
             }
             elsif($msg->type eq 'sess_message'){
                 my $sender_nick = "我";
@@ -77,14 +64,14 @@ sub call{
                 my $gname;
                 my $dname;
                 if($msg->via eq "group"){
-                    $receiver_nick = $msg->receiver->displayname;
+                    $receiver_nick = $msg->receiver->card||$msg->receiver->nick;
                     $gname = $msg->group->gname;
-                    $client->info({time=>$msg->msg_time,level=>"群临时消息",title=>"$sender_nick->$receiver_nick|$gname :"},$msg->content . $attach);
+                    $client->info({time=>$msg->msg_time,level=>"群临时消息",title=>"$sender_nick->$receiver_nick|$gname :"},$msg->content);
                 }
                 elsif($msg->via eq "discuss"){
-                    $receiver_nick = $msg->receiver->displayname;
+                    $receiver_nick = $msg->receiver->nick;
                     $dname = $msg->discuss->dname;
-                    $client->info({time=>$msg->msg_time,level=>"讨论组临时消息",title=>"$sender_nick->$receiver_nick|$dname :"},$msg->content . $attach);
+                    $client->info({time=>$msg->msg_time,level=>"讨论组临时消息",title=>"$sender_nick->$receiver_nick|$dname :"},$msg->content);
                 }
             }
         }
